@@ -11,6 +11,7 @@ test_that("Test on real and forec, length of output from selected functions", {
   expect_length(mdae(real, forec), 1)
   expect_length(mape(real, forec), 1)
   expect_length(smape(real, forec), 1)
+  expect_length(maape(real, forec), 1)
   expect_length(mase(real, forec, naive), 1)
 })
 
@@ -19,6 +20,7 @@ test_that("Test on real and forec, outputted values from acc. measures functions
   expect_equal(mae(c(4,5), c(2,4)), 1.5)
   expect_equal(mdae(c(4,5), c(2,4)), 1.5)
   expect_equal(mape(c(4,5), c(2,4)), 35)
+  expect_equal(maape(0, 1), pi/2)
   # expect_equal(smape(c(4,5), c(2,4)), 11111/250)
   expect_equal(mase(c(4,5), c(2,4), c(10,8)), 1/3)
 })
